@@ -75,7 +75,7 @@ sub _generate_accessor_any{
         $class->throw_error("Unknown accessor type '$type'");
     }
 
-    if ($attribute->is_lazy) {
+    if ($attribute->is_lazy and $type ne 'wo') {
         my $value;
 
         if (defined $builder){
@@ -88,7 +88,7 @@ sub _generate_accessor_any{
             $value = '$default';
         }
 
-        $accessor .= "els" if $type eq 'rw' || $type eq 'wo';
+        $accessor .= "els" if $type eq 'rw';
         $accessor .= "if(!exists $slot){\n";
         if($should_coerce){
             $accessor .= "$slot = \$constraint->coerce($value)";
@@ -182,7 +182,7 @@ Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
 
 =head1 VERSION
 
-This document describes Mouse version 0.53
+This document describes Mouse version 0.54
 
 =head1 SEE ALSO
 
